
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.8.0',
    'branch_nick': '(no',
    'revision_id': '8011e902f4516f24307d59298ebed7cade12a70e',
    'revno': 4447
}
